@@ -7,7 +7,14 @@ use std::{
     task::{Context, Poll},
 };
 
-use crate::{AsyncBatchHandler, Bus, Message, Untyped, buffer_unordered_batch_poller_macro, builder::ReceiverSubscriberBuilder, error::{Error, SendError, StdSyncSendError}, receiver::{Action, Event, ReciveTypedReceiver, SendUntypedReceiver, SendTypedReceiver}, receivers::{fix_type, Request}};
+use crate::{
+    buffer_unordered_batch_poller_macro,
+    builder::ReceiverSubscriberBuilder,
+    error::{Error, SendError, StdSyncSendError},
+    receiver::{Action, Event, ReciveTypedReceiver, SendTypedReceiver, SendUntypedReceiver},
+    receivers::{fix_type, Request},
+    AsyncBatchHandler, Bus, Message, Untyped,
+};
 
 use super::{BufferUnorderedBatchedConfig, BufferUnorderedBatchedStats};
 use futures::{stream::FuturesUnordered, Future, StreamExt};
@@ -39,7 +46,8 @@ where
     srx: Mutex<mpsc::UnboundedReceiver<Event<R, E>>>,
 }
 
-impl<T, M, R> ReceiverSubscriberBuilder<T, M, R, T::Error> for BufferUnorderedBatchedAsync<M, R, T::Error>
+impl<T, M, R> ReceiverSubscriberBuilder<T, M, R, T::Error>
+    for BufferUnorderedBatchedAsync<M, R, T::Error>
 where
     T: AsyncBatchHandler<M, Response = R> + 'static,
     T::Error: StdSyncSendError + Clone,
@@ -99,7 +107,7 @@ where
     R: Message,
     E: StdSyncSendError,
 {
-    fn send(&self, m: Action) -> Result<(), SendError<Action>> {
+    fn send(&self, m: Action, _bus: &Bus) -> Result<(), SendError<Action>> {
         match self.tx.send(Request::Action(m)) {
             Ok(_) => Ok(()),
             Err(mpsc::error::SendError(Request::Action(msg))) => Err(SendError::Closed(msg)),
@@ -114,7 +122,7 @@ where
     R: Message,
     E: StdSyncSendError,
 {
-    fn send(&self, mid: u64, m: M) -> Result<(), SendError<M>> {
+    fn send(&self, mid: u64, m: M, _bus: &Bus) -> Result<(), SendError<M>> {
         match self.tx.send(Request::Request(mid, m)) {
             Ok(_) => {
                 self.stats.buffer.fetch_add(1, Ordering::Relaxed);
@@ -133,7 +141,7 @@ where
     R: Message,
     E: StdSyncSendError,
 {
-    fn poll_events(&self, ctx: &mut Context<'_>) -> Poll<Event<R, E>> {
+    fn poll_events(&self, ctx: &mut Context<'_>, _bus: &Bus) -> Poll<Event<R, E>> {
         let poll = self.srx.lock().poll_recv(ctx);
         match poll {
             Poll::Pending => Poll::Pending,
