@@ -5,11 +5,11 @@ use std::{
 };
 
 use crate::{
-    batch_synchronized_poller_macro, 
+    batch_synchronized_poller_macro,
     builder::ReceiverSubscriberBuilder,
-    error::{Error, StdSyncSendError, SendError}, 
-    receiver::{Action, Event, ReciveTypedReceiver, SendUntypedReceiver, SendTypedReceiver}, 
-    receivers::{fix_type, Request},
+    error::{Error, SendError, StdSyncSendError},
+    receiver::{Action, Event, ReciveTypedReceiver, SendTypedReceiver, SendUntypedReceiver},
+    receivers::{fix_into_iter, fix_type, Request},
     BatchSynchronizedHandler, Bus, Message, Untyped,
 };
 
@@ -44,7 +44,8 @@ where
     srx: parking_lot::Mutex<mpsc::UnboundedReceiver<Event<R, E>>>,
 }
 
-impl<T, M, R> ReceiverSubscriberBuilder<T, M, R, T::Error> for SynchronizedBatchedSync<M, R, T::Error>
+impl<T, M, R> ReceiverSubscriberBuilder<T, M, R, T::Error>
+    for SynchronizedBatchedSync<M, R, T::Error>
 where
     T: BatchSynchronizedHandler<M, Response = R> + 'static,
     T::Error: StdSyncSendError,
@@ -66,9 +67,8 @@ where
 
         let poller = Box::new(move |ut| {
             Box::new(move |bus| {
-                Box::pin(batch_synchronized_poller::<T, M, R>(
-                    rx, bus, ut, cfg, stx,
-                )) as Pin<Box<dyn Future<Output = ()> + Send>>
+                Box::pin(batch_synchronized_poller::<T, M, R>(rx, bus, ut, cfg, stx))
+                    as Pin<Box<dyn Future<Output = ()> + Send>>
             }) as Box<dyn FnOnce(Bus) -> Pin<Box<dyn Future<Output = ()> + Send>>>
         });
 
@@ -88,7 +88,7 @@ where
     R: Message,
     E: StdSyncSendError,
 {
-    fn send(&self, msg: Action) -> Result<(), SendError<Action>> {
+    fn send(&self, msg: Action, _bus: &Bus) -> Result<(), SendError<Action>> {
         match self.tx.send(Request::Action(msg)) {
             Ok(_) => Ok(()),
             Err(mpsc::error::SendError(Request::Action(msg))) => Err(SendError::Closed(msg)),
@@ -103,7 +103,7 @@ where
     R: Message,
     E: StdSyncSendError,
 {
-    fn send(&self, mid: u64, m: M) -> Result<(), SendError<M>> {
+    fn send(&self, mid: u64, m: M, _bus: &Bus) -> Result<(), SendError<M>> {
         match self.tx.send(Request::Request(mid, m)) {
             Ok(_) => Ok(()),
             Err(mpsc::error::SendError(Request::Request(_, msg))) => Err(SendError::Closed(msg)),
@@ -118,7 +118,7 @@ where
     R: Message,
     E: StdSyncSendError,
 {
-    fn poll_events(&self, ctx: &mut Context<'_>) -> Poll<Event<R, E>> {
+    fn poll_events(&self, ctx: &mut Context<'_>, _bus: &Bus) -> Poll<Event<R, E>> {
         let poll = self.srx.lock().poll_recv(ctx);
         match poll {
             Poll::Pending => Poll::Pending,
