@@ -5,15 +5,15 @@ use std::{
 };
 
 use crate::synchronized_poller_macro;
-use futures::{Future, executor::block_on};
+use futures::{executor::block_on, Future};
 
 use super::SynchronizedConfig;
 use crate::{
-    error::{Error, StdSyncSendError, SendError},
     builder::ReceiverSubscriberBuilder,
-    receiver::{SendTypedReceiver, Action, Event, ReciveTypedReceiver, SendUntypedReceiver},
+    error::{Error, SendError, StdSyncSendError},
+    receiver::{Action, Event, ReciveTypedReceiver, SendTypedReceiver, SendUntypedReceiver},
     receivers::{fix_type, Request},
-    SynchronizedHandler, Bus, Message, Untyped,
+    Bus, Message, SynchronizedHandler, Untyped,
 };
 use tokio::sync::{mpsc, Mutex};
 
@@ -87,7 +87,7 @@ where
     R: Message,
     E: StdSyncSendError,
 {
-    fn send(&self, msg: Action) -> Result<(), SendError<Action>> {
+    fn send(&self, msg: Action, _bus: &Bus) -> Result<(), SendError<Action>> {
         match self.tx.send(Request::Action(msg)) {
             Ok(_) => Ok(()),
             Err(mpsc::error::SendError(Request::Action(msg))) => Err(SendError::Closed(msg)),
@@ -102,7 +102,7 @@ where
     R: Message,
     E: StdSyncSendError,
 {
-    fn send(&self, mid: u64, m: M) -> Result<(), SendError<M>> {
+    fn send(&self, mid: u64, m: M, _bus: &Bus) -> Result<(), SendError<M>> {
         match self.tx.send(Request::Request(mid, m)) {
             Ok(_) => Ok(()),
             Err(mpsc::error::SendError(Request::Request(_, msg))) => Err(SendError::Closed(msg)),
@@ -117,7 +117,7 @@ where
     R: Message,
     E: StdSyncSendError,
 {
-    fn poll_events(&self, ctx: &mut Context<'_>) -> Poll<Event<R, E>> {
+    fn poll_events(&self, ctx: &mut Context<'_>, _bus: &Bus) -> Poll<Event<R, E>> {
         let poll = self.srx.lock().poll_recv(ctx);
         match poll {
             Poll::Pending => Poll::Pending,
